KSM edits to RA8875

Dependents:   Liz_Test_Code

Revision:
103:7e0464ca6c5c
Parent:
102:fc60bfa0199f
Child:
105:4f116006ba1f
--- a/RA8875.h	Sat Jan 23 16:58:54 2016 +0000
+++ b/RA8875.h	Sun Feb 07 23:18:01 2016 +0000
@@ -579,7 +579,7 @@
     ///    } while (t.read_ms() < 30000);
     /// @endcode
     ///
     /// @param[out] TouchPoint is the touch point, if a touch is registered.
     /// @returns a value indicating the state of the touch,
     ///         - no_cal:   no calibration matrix is available, touch coordinates are not returned.
     ///         - no_touch: no touch is detected, touch coordinates are not returned.
@@ -984,6 +984,20 @@
     ///
     RetCode_t SetTextCursor(loc_t x, loc_t y);
 
+    /// Prepare the controller to write text to the screen by positioning
+    /// the cursor.
+    ///
+    /// @code
+    ///     point_t point = {100, 25};
+    ///     lcd.SetTextCursor(point);
+    ///     lcd.puts("Hello");
+    /// @endcode
+    ///
+    /// @param[in] p is the x:y point in pixels from the top-left.
+    /// @returns success/failure code. @see RetCode_t.
+    ///
+    RetCode_t SetTextCursor(point_t p);
+
     /// Get the current cursor position in pixels.
     ///
     /// @code
@@ -579,7 +579,7 @@
     /// @endcode
     ///
-    /// @param[out] TouchPoint is the touch point, if a touch is registered.
+    /// @param[inout] TouchPoint is a pointer to a point_t, which is set as the touch point, if a touch is registered.
     /// @returns a value indicating the state of the touch,
     ///         - no_cal:   no calibration matrix is available, touch coordinates are not returned.